@@ -40,7 +40,7 @@ class BenchmarkOperatorWorkloadsOperations:
         self._key = self._environment_variables_dict.get('key', '')
         self._endpoint_url = self._environment_variables_dict.get('endpoint_url', '')
         self._save_artifacts_local = self._environment_variables_dict.get('save_artifacts_local', '')
-        self._enable_prometheus_snapshot = self._environment_variables_dict.get('enable_prometheus_snapshot', '')
+        self._enable_prometheus_snapshot = self._environment_variables_dict.get('enable_prometheus_snapshot', False)
         self._kubeadmin_password = self._environment_variables_dict.get('kubeadmin_password', '')
         self._dir_path = f'{os.path.dirname(os.path.realpath(__file__))}'
         self._pin_node_benchmark_operator = self._environment_variables_dict.get('pin_node_benchmark_operator', '')
@@ -350,7 +350,7 @@ class BenchmarkOperatorWorkloadsOperations:
         :return: run artifacts url
         """
         self._create_pod_log(label='benchmark-controller-manager')
-        if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+        if environment_variables.environment_variables_dict['system_metrics']:
             self._create_pod_log(label='system-metrics')
         # for vm call to create_vm_log
         if pod:
@@ -375,11 +375,26 @@ class BenchmarkOperatorWorkloadsOperations:
             archive.add(self._run_artifacts_path, arcname=f'{workload}-{self._time_stamp_format}', recursive=True)
         return tar_run_artifacts_path
 
+    @logger_time_stamp
+    def delete_local_artifacts(self):
+        """
+        This method delete local artifacts
+        :return:
+        """
+        workload = self._workload_name
+        tar_run_artifacts_path = self.__make_run_artifacts_tarfile(workload)
+        # remove local run artifacts workload folder
+        # verify that its not empty path
+        if len(self._run_artifacts_path) > 3 and self._run_artifacts_path != '/' and self._run_artifacts_path and tar_run_artifacts_path and os.path.isfile(tar_run_artifacts_path) and not self._save_artifacts_local:
+            # remove run_artifacts_path
+            shutil.rmtree(path=self._run_artifacts_path)
+            # remove tar.gz file
+            os.remove(path=tar_run_artifacts_path)
+
     @logger_time_stamp
     def upload_run_artifacts_to_s3(self):
         """
         This method uploads log to s3
-        :param workload:
         :return:
         """
         workload = self._workload_name
@@ -393,13 +408,6 @@ class BenchmarkOperatorWorkloadsOperations:
                                  bucket=self._environment_variables_dict.get('bucket', ''),
                                  key=run_artifacts_hierarchy,
                                  upload_file=upload_file)
-        # remove local run artifacts workload folder
-        # verify that its not empty path
-        if len(self._run_artifacts_path) > 3 and self._run_artifacts_path != '/' and self._run_artifacts_path and tar_run_artifacts_path and os.path.isfile(tar_run_artifacts_path) and not self._save_artifacts_local:
-            # remove run_artifacts_path
-            shutil.rmtree(path=self._run_artifacts_path)
-            # remove tar.gz file
-            os.remove(path=tar_run_artifacts_path)
 
     @logger_time_stamp
     def start_prometheus(self):
@@ -467,7 +475,7 @@ class BenchmarkOperatorWorkloadsOperations:
         self.clear_nodes_cache()
         # make deploy benchmark controller manager
         self.make_deploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
-        if self._odf_pvc == 'True':
+        if self._odf_pvc:
             self.odf_pvc_verification()
         self._template.generate_yamls()
         if self._enable_prometheus_snapshot:
@@ -482,4 +490,6 @@ class BenchmarkOperatorWorkloadsOperations:
             self.end_prometheus()
         if self._endpoint_url:
             self.upload_run_artifacts_to_s3()
+        if not self._save_artifacts_local:
+            self.delete_local_artifacts()
         self.delete_all()
