@@ -62,7 +62,7 @@ class HammerdbPod(BenchmarkOperatorWorkloadsOperations):
             self.__status = self._oc.wait_for_pod_completed(label='app=hammerdb_workload', workload=self.__workload_name)
             self.__status = 'complete' if self.__status else 'failed'
             # system metrics
-            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+            if environment_variables.environment_variables_dict['system_metrics']:
                 self.system_metrics_collector(workload=self.__workload_name)
             # save run artifacts logs
             run_artifacts_url = self._create_run_artifacts(labels=[f'{self.__workload_name}-creator', f'{self.__workload_name}-workload'], database=self.__database)
@@ -114,4 +114,4 @@ class HammerdbPod(BenchmarkOperatorWorkloadsOperations):
             # delete database
             self._oc.delete_pod_sync(yaml=os.path.join(f'{self._run_artifacts_path}', f'{self.__database}.yaml'), pod_name=self.__database,
                                      namespace=f'{self.__database}-db')
-            raise err
\ No newline at end of file
+            raise err
