@@ -48,7 +48,7 @@ class StressngPod(BenchmarkOperatorWorkloadsOperations):
             self.__status = self._oc.wait_for_pod_completed(label='app=stressng_workload', workload=self.__workload_name)
             self.__status = 'complete' if self.__status else 'failed'
             # system metrics
-            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+            if environment_variables.environment_variables_dict['system_metrics']:
                 self.system_metrics_collector(workload=self.__workload_name)
             # save run artifacts logs
             run_artifacts_url = self._create_run_artifacts(workload=self.__workload_name)
