@@ -44,7 +44,7 @@ class StressngVM(BenchmarkOperatorWorkloadsOperations):
             self.__status = self._oc.wait_for_vm_completed(workload=self.__workload_name, vm_name=vm_name)
             self.__status = 'complete' if self.__status else 'failed'
             # system metrics
-            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+            if environment_variables.environment_variables_dict['system_metrics']:
                 self.system_metrics_collector(workload=self.__workload_name)
             # save run artifacts logs of benchmark-controller-manager and system-metrics
             run_artifacts_url = self._create_run_artifacts(workload=self.__workload_name, pod=False)
@@ -76,4 +76,4 @@ class StressngVM(BenchmarkOperatorWorkloadsOperations):
                     self._verify_elasticsearch_data_uploaded(index=self.__es_index, uuid=self._uuid)
             self.tear_down_vm_after_error(yaml=os.path.join(f'{self._run_artifacts_path}', f'{self.__name}.yaml'),
                                           vm_name=f'{self.__workload_name}-workload')
-            raise err
\ No newline at end of file
+            raise err
