@@ -46,10 +46,7 @@ class UperfPod(BenchmarkOperatorWorkloadsOperations):
             # uperf server
             server_name = self._environment_variables_dict.get('pin_node1', '')
             if server_name:
-                # uperf server name is limited up to 27 chars
-                if len(server_name) > 27:
-                    server_name = server_name[:28]
-                label = f'app=uperf-bench-server-{server_name}-0'
+                label = f'app=uperf-bench-server-0'
                 self._oc.wait_for_initialized(label=label, workload=self.__workload_name)
                 self._oc.wait_for_ready(label=label, workload=self.__workload_name)
             # in case that no pin node
@@ -64,7 +61,7 @@ class UperfPod(BenchmarkOperatorWorkloadsOperations):
             self.__status = self._oc.wait_for_pod_completed(label='app=uperf-bench-client', workload=self.__workload_name)
             self.__status = 'complete' if self.__status else 'failed'
             # system metrics
-            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+            if environment_variables.environment_variables_dict['system_metrics']:
                 self.system_metrics_collector(workload=self.__workload_name)
             # save run artifacts logs
             run_artifacts_url = self._create_run_artifacts(workload=self.__workload_name, labels=['uperf-client', 'uperf-server'])
@@ -98,4 +95,4 @@ class UperfPod(BenchmarkOperatorWorkloadsOperations):
                     self._upload_to_elasticsearch(index=self.__es_index, kind=self.__kind, status='failed', run_artifacts_url=run_artifacts_url, uuid=self._uuid)
                     self._verify_elasticsearch_data_uploaded(index=self.__es_index, uuid=self._uuid)
             self.tear_down_pod_after_error(yaml=os.path.join(f'{self._run_artifacts_path}', f'{self.__name}.yaml'), pod_name=f'uperf-client')
-            raise err
\ No newline at end of file
+            raise err
