@@ -274,7 +274,7 @@ class OC(SSH):
         if major_version <= 4 and minor_version <= 10:
             prom_token = self.run(f"{self.__cli} -n openshift-monitoring sa get-token prometheus-k8s")
         else:
-            prom_token = self.run(f"{self.__cli} sa new-token -n openshift-monitoring prometheus-k8s")
+            prom_token = self.run(f"{self.__cli} sa new-token -n openshift-monitoring prometheus-k8s 2>/dev/null")
         return prom_token
 
     @logger_time_stamp
@@ -598,10 +598,10 @@ class OC(SSH):
             if 'met' in result.decode("utf-8"):
                 return True
         except Exception as err:
-            if 'pod' in workload:
-                raise PodNotReadyTimeout(workload=workload)
-            else:
+            if 'vm' in workload:
                 raise VMNotReadyTimeout(workload=workload)
+            else:
+                raise PodNotReadyTimeout(workload=workload)
 
     @typechecked
     @logger_time_stamp
