@@ -29,7 +29,7 @@ class WorkloadsOperations:
         self._workload = self._environment_variables_dict.get('workload', '')
         self._build_version = self._environment_variables_dict.get('build_version', '')
         self._workloads_odf_pvc = list(self._environment_variables_dict.get('workloads_odf_pvc', ''))
-        self._odf_pvc = self._environment_variables_dict.get('odf_pvc', '')
+        self._odf_pvc = self._environment_variables_dict.get('odf_pvc', True)
         self._kubeadmin_password = self._environment_variables_dict.get('kubeadmin_password', '')
         self._run_type = self._environment_variables_dict.get('run_type', '')
         self._trunc_uuid = self._environment_variables_dict.get('trunc_uuid', '')
@@ -40,7 +40,7 @@ class WorkloadsOperations:
         self._endpoint_url = self._environment_variables_dict.get('endpoint_url', '')
         self._run_artifacts_path = self._environment_variables_dict.get('run_artifacts_path', '')
         self._save_artifacts_local = self._environment_variables_dict.get('save_artifacts_local', '')
-        self._enable_prometheus_snapshot = self._environment_variables_dict.get('enable_prometheus_snapshot', '')
+        self._enable_prometheus_snapshot = self._environment_variables_dict.get('enable_prometheus_snapshot', False)
         self._run_artifacts_url = self._environment_variables_dict.get('run_artifacts_url', '')
         self._pin_node1 = self._environment_variables_dict.get('pin_node1', '')
         self._pin_node2 = self._environment_variables_dict.get('pin_node2', '')
@@ -275,6 +275,22 @@ class WorkloadsOperations:
             archive.add(self._run_artifacts_path, arcname=workload_file_name, recursive=True)
         return tar_run_artifacts_path
 
+    @logger_time_stamp
+    def delete_local_artifacts(self):
+        """
+        This method delete local artifacts
+        :return:
+        """
+        workload = self._workload.replace('_', '-')
+        tar_run_artifacts_path = self.__make_run_artifacts_tarfile(workload)
+        # remove local run artifacts workload folder
+        # verify that its not empty path
+        if len(self._run_artifacts_path) > 3 and self._run_artifacts_path != '/' and self._run_artifacts_path and tar_run_artifacts_path and os.path.isfile(tar_run_artifacts_path):
+            # remove run_artifacts_path
+            shutil.rmtree(path=self._run_artifacts_path)
+            # remove tar.gz file
+            os.remove(path=tar_run_artifacts_path)
+
     @logger_time_stamp
     def upload_run_artifacts_to_s3(self):
         """
@@ -293,13 +309,6 @@ class WorkloadsOperations:
                                  bucket=self._environment_variables_dict.get('bucket', ''),
                                  key=run_artifacts_hierarchy,
                                  upload_file=upload_file)
-        # remove local run artifacts workload folder
-        # verify that its not empty path
-        if len(self._run_artifacts_path) > 3 and self._run_artifacts_path != '/' and self._run_artifacts_path and tar_run_artifacts_path and os.path.isfile(tar_run_artifacts_path) and not self._save_artifacts_local:
-            # remove run_artifacts_path
-            shutil.rmtree(path=self._run_artifacts_path)
-            # remove tar.gz file
-            os.remove(path=tar_run_artifacts_path)
 
     def __get_metadata(self, kind: str = None, status: str = None, result: dict = None) -> dict:
         """
@@ -326,7 +335,7 @@ class WorkloadsOperations:
         if status:
             metadata.update({'run_status': status})
         if self._scale:
-            metadata.update({'scale': int(self._scale)})
+            metadata.update({'scale': int(self._scale)*len(self._scale_node_list)})
             count = 0
             for scale_node in range(len(self._scale_node_list)):
                 for scale_num in range(self._scale):
@@ -397,7 +406,7 @@ class WorkloadsOperations:
         """
         self.delete_all()
         self.clear_nodes_cache()
-        if self._odf_pvc == 'True':
+        if self._odf_pvc:
             self.odf_pvc_verification()
         self._template.generate_yamls(scale=str(self._scale), scale_nodes=self._scale_node_list)
         if self._enable_prometheus_snapshot:
@@ -412,4 +421,6 @@ class WorkloadsOperations:
             self.end_prometheus()
         if self._endpoint_url:
             self.upload_run_artifacts_to_s3()
+        if not self._save_artifacts_local:
+            self.delete_local_artifacts()
         self.delete_all()
